using Microsoft.SharePoint;
using System;

namespace RH
{
    class Common
    {
        /// <summary>
        /// Gets the specified list. If it does not exist, returns null
        /// </summary>
        /// <param name="web"></param>
        /// <param name="listName"></param>
        /// <returns></returns>
        public static SPList GetList(SPWeb web, string listName)
        {
            foreach (SPList list in web.Lists)
            {
                if (list.Title == listName)
                    return list;
            }

            return null;
        }

        private static SPFeature GetFeature(SPFeatureCollection features, Guid featureID)
        {
            foreach (SPFeature feature in features)
            {
                if (feature.DefinitionId == featureID) return feature;
            }
            return null;
        }

        internal static string EnableSiteFeature(SPSite site, Guid featureGuid, bool enable)
        {
            var feature = GetFeature(site.Features, featureGuid);
            if (enable)
            {
                if (feature != null)
                {
                    return string.Format("The feature '{0}' is already activated on {1}", feature.Definition.DisplayName, site.Url);
                }
                try
                {
                    feature = site.Features.Add(featureGuid);
                    return string.Format("Feature '{0}' activated on {1}", feature.Definition.DisplayName, site.Url);
                }
                catch (Exception ex)
                {
                    return string.Format("Error adding the feature with ID {0} to {1}: {2}", featureGuid, site.Url, ex.Message);
                }
            }
            
            // disable
            if (feature == null)
            {
                return string.Format("The feature with ID {0} is not activated at {1}", featureGuid, site.Url);
            }
            try
            {
                site.Features.Remove(featureGuid);
                return string.Format("Feature '{0} has been deactivated on {1}", feature.Definition.DisplayName, site.Url);
            }
            catch (Exception ex)
            {
                return string.Format("Error removing the feature '{0}': {1}", feature.Definition.DisplayName, ex.Message);
            }
        }

        internal static string EnableWebFeature(SPWeb web, Guid featureGuid, bool enable)
        {
            var feature = GetFeature(web.Features, featureGuid);
            if (enable)
            {
                if (feature != null)
                {
                    return string.Format("The feature '{0}' is already activated on {1}", feature.Definition.DisplayName, web.Url);
                }
                try
                {
                    feature = web.Features.Add(featureGuid);
                    return string.Format("Feature '{0}' activated on {1}", feature.Definition.DisplayName, web.Url);
                }
                catch (Exception ex)
                {
                    return string.Format("Error adding the feature with ID {0} to {1}: {2}", featureGuid, web.Url, ex.Message);
                }
            }

            // disable
            if (feature == null)
            {
                return string.Format("The feature with ID {0} is not activated at {1}", featureGuid, web.Url);
            }
            try
            {
                web.Features.Remove(featureGuid);
                return string.Format("Feature '{0} has been deactivated on {1}", feature.Definition.DisplayName, web.Url);
            }
            catch (Exception ex)
            {
                return string.Format("Error removing the feature '{0}': {1}", feature.Definition.DisplayName, ex.Message);
            }
        }

    }
}
