using System;
using Microsoft.SharePoint;
using System.IO;

namespace RH
{
    static class ListItems
    {
        /// <summary>
        /// Deletes listItems from a list
        /// </summary>
        /// <param name="web"></param>
        /// <param name="listName"></param>
        /// <param name="action">'Delete' or 'Recycle'</param>
        /// <param name="versions">true of false</param>
        public static void DeleteListItems(SPWeb web, string listName, string action, bool versions)
        {
            try
            {
                if (String.IsNullOrEmpty(listName))
                {
                    Usage.ShowUsage();
                    return;
                }

                SPList list = Common.GetList(web, listName);
                if (list == null)
                {
                    Console.WriteLine(string.Format("List '{0}' not found.", listName));
                    return;
                }

            	SPListItemCollection listItems = list.Items;
            	int itemCount = listItems.Count;

                Console.WriteLine(String.Format("Working on {0} listItems from '{1}'\r\n", itemCount, listName));

                for (int i = itemCount - 1; i >= 0; i--)
                {
                    Console.Write(".");
                    int itemId = listItems[i].ID;
                    SPListItem item = list.GetItemById(itemId);

                    if (action == "Delete")
                    {
                        if (versions)
                            item.Versions.DeleteAll();
                        else
                            item.Delete();
                    }
                    else
                    {
                        if (versions)
                            item.Versions.RecycleAll();
                        else
                            item.Recycle();
                    }
                }

                if (versions)
                    Console.WriteLine(String.Format("\r\n{0}d all Versions on {1} listItems.", action, itemCount));
                else
                    Console.WriteLine(String.Format("\r\n{0}d {1} listItems.", action, itemCount));
            }
            catch (Exception ex)
            {
                Console.WriteLine(string.Format("Error {0}ing ListItems from '{1}':\r\n{2}", action, listName, ex));
            }
        }

        /// <summary>
        /// Sets the Title with the Filename without the extension
        /// </summary>
        /// <param name="web"></param>
        /// <param name="listName"></param>
        internal static void SetTitleWithFilename(SPWeb web, string listName)
        {
            try
            {
                if (String.IsNullOrEmpty(listName))
                {
                    Usage.ShowUsage();
                    return;
                }

                SPList list = Common.GetList(web, listName);
                if (list == null)
                {
                    Console.WriteLine(string.Format("List '{0}' not found.", listName));
                    return;
                }

            	SPField titleField = list.Fields[SPBuiltInFieldId.Title];
            	Guid titleFieldId = titleField.Id;
            	SPListItemCollection listItems = list.Items;
            	int itemCount = listItems.Count;

                Console.WriteLine(String.Format("Working on {0} listItems from '{1}'\r\n", itemCount, listName));

                for (int i = itemCount - 1; i >= 0; i--)
                {
                    Console.Write(".");
                    int itemId = listItems[i].ID;
                    SPListItem item = list.GetItemById(itemId);

                    string newTitle = Path.GetFileNameWithoutExtension(item.Name);
						  item[titleFieldId] = newTitle;
                    item.SystemUpdate(false);
                }

                Console.WriteLine(String.Format("\r\nSet title on {0} listItems.", itemCount));
            }
            catch (Exception ex)
            {
                Console.WriteLine(string.Format("Error setting the title on '{0}':\r\n{1}", listName, ex));
            }
        }
    }
}
