using System;
using Microsoft.SharePoint;
using System.Threading;

namespace RH
{
	class Lists
	{
		/// <summary>
		/// Changes the visibilty of a field
		/// </summary>
		/// <param name="web"></param>
		/// <param name="listName"></param>
		/// <param name="fieldName"></param>
		/// <param name="visibility"></param>
		/// <param name="formName"></param>
		public static void ShowInForm(SPWeb web, string listName, string fieldName, string visibility, string formName)
		{
			try
			{
				SPList list = Common.GetList(web, listName);
				if (list == null)
				{
					Console.WriteLine(string.Format("List '{0}' not found.", listName));
					return;
				}

				if (!list.Fields.ContainsField(fieldName))
				{
					Console.WriteLine(string.Format("List '{0}' does not contain a field '{1}'.", listName, fieldName));
					return;
				}
				SPField field = list.Fields.GetField(fieldName);

				bool showField;
				if (!bool.TryParse(visibility, out showField))
				{
					Console.WriteLine(string.Format("'{0}' is not a valid bool.", visibility));
					return;
				}

				if (formName == "EditForm")
					field.ShowInEditForm = showField;
				else if (formName == "NewForm")
					field.ShowInNewForm = showField;
				else if (formName == "DisplayForm")
					field.ShowInDisplayForm = showField;

				field.Update(true);

				Console.WriteLine(string.Format("Field '{0}' updated. Visibility is now '{1}'.", fieldName, visibility));
			}
			catch (Exception ex)
			{
				Console.WriteLine(string.Format("Error setting visibility of {0}:\r\n{1}", listName, ex));
			}
		}

		internal static void SystemUpdate(SPWeb web, string listName, string sleepTime, string itemId)
		{
			SPList list = Common.GetList(web, listName);
			if (list == null)
			{
				Console.WriteLine(string.Format("List '{0}' not found.", listName));
				return;
			}

			int id;
			if (string.IsNullOrEmpty(itemId))
			{
				int sleep;
				int.TryParse(sleepTime, out sleep);
				sleep = sleep * 1000;

				SPListItemCollection listItems = list.Items;
				int itemCount = listItems.Count;
				for (int i = 0; i < itemCount; i++)
				{
					try
					{
						Console.Write(".");
						var item = listItems[i];
						item.SystemUpdate(false);
						Thread.Sleep(sleep);
					}
					catch (Exception ex)
					{
						Console.WriteLine("Error updating item: {0}", ex.Message);
					}
				}
				Console.Write(Environment.NewLine);
			}
			else if (int.TryParse(itemId, out id) && id > 0)
			{
				try
				{
					SPListItem item = list.GetItemById(id);
					item.SystemUpdate(false);
					Console.WriteLine("Updated item with ID {0}", id);
				}
				catch (Exception ex)
				{
					Console.WriteLine("Error updating item: {0}", ex.Message);
				}
			}
		}
	}
}