using System;
using Microsoft.SharePoint;

namespace RH
{
	class SharePointConsole
	{
		private static readonly Version _Version = new Version(1, 1, 0, 0);

		static void Main(string[] args)
		{
			Console.WriteLine(string.Format("SharePointConsole Version {0} from http://www.hezser.de", _Version));
			if (args == null || args.Length < 2)
			{
				Usage.ShowUsage();
				return;
			}

			SPSite site = null;
			SPWeb web = null;
			try
			{
				string command = string.Empty;
				string parameter1 = string.Empty;
				string parameter2 = string.Empty;
				string parameter3 = string.Empty;
				if (args.Length >= 2)
				{
					command = args[1];
				}
				if (args.Length >= 3)
				{
					parameter1 = args[2];
				}
				if (args.Length >= 4)
				{
					parameter2 = args[3];
				}
				if (args.Length >= 5)
				{
					parameter3 = args[4];
				}

				Console.WriteLine(string.Format("Opening Site '{0}'...", args[0]));
				site = new SPSite(args[0]);
				Console.WriteLine(string.Format("Opening Web '{0}'...", args[0]));
				web = site.OpenWeb();

				switch (command)
				{
					case "EnumContentTypes":
						ContentTypes.EnumContentTypes(web);
						break;
					case "CreateContentType":
						ContentTypes.CreateContentType(web, parameter1, parameter2);
						break;
					case "RenameContentType":
						ContentTypes.RenameContentType(web, parameter1, parameter2);
						break;
					case "DeleteContentType":
						ContentTypes.DeleteContentType(web, parameter1);
						break;
					case "DeleteAllListItems":
						ListItems.DeleteListItems(web, parameter1, "Delete", false);
						break;
					case "RecycleAllListItems":
						ListItems.DeleteListItems(web, parameter1, "Recycle", false);
						break;
					case "ShowInEditForm":
						Lists.ShowInForm(web, parameter1, parameter2, parameter3, "EditForm");
						break;
					case "ShowInDisplayForm":
						Lists.ShowInForm(web, parameter1, parameter2, parameter3, "DisplayForm");
						break;
					case "ShowInNewForm":
						Lists.ShowInForm(web, parameter1, parameter2, parameter3, "NewForm");
						break;
					case "DeleteAllVersions":
						ListItems.DeleteListItems(web, parameter1, "Delete", true);
						break;
					case "RecycleAllVersions":
						ListItems.DeleteListItems(web, parameter1, "Recycle", true);
						break;
					case "SetTitleWithFilename":
						ListItems.SetTitleWithFilename(web, parameter1);
						break;
					case "SetSearchCenterUrl":
						Webs.SetSearchCenterUrl(site, parameter1);
						break;
					case "SystemUpdate":
						Lists.SystemUpdate(web, parameter1, parameter2, parameter3);
						break;
					case "FeatureManager":
						Webs.FeatureManager(site, web, parameter1, parameter2, parameter3);
						break;
					case "EmptyRecycleBin":
						Webs.EmptyRecycleBin(site);
						break;
					default:
						Console.WriteLine(string.Format("Command '{0}' not found.", command));
						break;
				}
#if DEBUG
				Console.WriteLine("Press Enter to continue...");
				Console.ReadLine();
#endif
			}
			catch (Exception ex)
			{
				Console.WriteLine(string.Format("Error creating a reference to the site '{0}':\r\n{1}", args[0], ex.Message));
			}
			finally
			{
				if (site != null)
					site.Dispose();

				if (web != null)
					web.Dispose();
			}
		}
	}
}