﻿using System;
using Microsoft.SharePoint;
using Microsoft.SharePoint.Administration;

namespace RH
{
	class Webs
	{
		/// <summary>
		/// Set the Search Center URL for the entire Webapplication
		/// </summary>
		/// <param name="site"></param>
		/// <param name="searchCenterUrl"></param>
		internal static void SetSearchCenterUrl(SPSite site, string searchCenterUrl)
		{
			try
			{
				SPWebApplication webApplication = site.WebApplication;
				foreach (SPSite currentSite in webApplication.Sites)
				{
					using (var rootWeb = currentSite.RootWeb)
					{
						bool allowUnsafeUpdates = rootWeb.AllowUnsafeUpdates;
						rootWeb.AllowUnsafeUpdates = true;

						Console.WriteLine(String.Format("Setting SearchCenterUrl for Sitecollection '{0}'", rootWeb.Url));
						rootWeb.AllProperties["SRCH_ENH_FTR_URL"] = searchCenterUrl;
						rootWeb.Update();

						rootWeb.AllowUnsafeUpdates = allowUnsafeUpdates;
					}

					currentSite.Dispose();
				}
			}
			catch (Exception ex)
			{
				Console.WriteLine(string.Format("Error setting SearchCenterUrl for site {0}:\r\n{1}", site.Url, ex));
			}
		}

		internal static void FeatureManager(SPSite site, SPWeb web, string featureId, string enableDisable, string allSitesWebs)
		{
			try
			{
				var enableFeature = enableDisable.ToLower() == "enable" ? true : false;
				var featureGuid = new Guid(featureId);
				string message = Common.EnableSiteFeature(site, featureGuid, enableFeature);
				Console.WriteLine(message);

				message = Common.EnableWebFeature(web, featureGuid, enableFeature);
				Console.WriteLine(message);

				switch (allSitesWebs)
				{
					case "Farm":
						SPWebService contentService = SPWebService.ContentService;
						foreach (SPWebApplication webApplication in contentService.WebApplications)
						{
							FeatureManagerSite(featureGuid, enableFeature, webApplication);
						}
						break;
					case "AllSites":
						FeatureManagerSite(featureGuid, enableFeature, site.WebApplication);
						break;
					case "AllWebs":
						FeatureManagerWeb(site, featureGuid, enableFeature);
						break;
				}
			}
			catch (Exception ex)
			{
				Console.WriteLine(string.Format("Error setting FeatureManager for {0}:\r\n{1}", site.Url, ex));
			}
		}

		/// <summary>
		/// work on the feature in every site and web of the webapplication
		/// </summary>
		/// <param name="featureGuid"></param>
		/// <param name="enableFeature"></param>
		/// <param name="webApplication"></param>
		private static void FeatureManagerSite(Guid featureGuid, bool enableFeature, SPWebApplication webApplication)
		{
			foreach (SPSite site in webApplication.Sites)
			{
				string message = Common.EnableSiteFeature(site, featureGuid, enableFeature);
				Console.WriteLine(message);

				FeatureManagerWeb(site, featureGuid, enableFeature);
				site.Dispose();
			}
		}

		/// <summary>
		/// work on the feature in every SPWeb within the SPSite
		/// </summary>
		/// <param name="site"></param>
		/// <param name="featureGuid"></param>
		/// <param name="enableFeature"></param>
		private static void FeatureManagerWeb(SPSite site, Guid featureGuid, bool enableFeature)
		{
			foreach (SPWeb web in site.AllWebs)
			{
				string message = Common.EnableWebFeature(web, featureGuid, enableFeature);
				Console.WriteLine(message);
				web.Dispose();
			}
		}

		public static void EmptyRecycleBin(SPSite site)
		{
			int itemsInRecycleBin = site.RecycleBin.Count;
			Console.WriteLine(string.Format("Deleting {0} item{1}...", itemsInRecycleBin, itemsInRecycleBin == 1 ? "" : "s"));

			site.RecycleBin.DeleteAll();
		}
	}
}